==> em_celery-0.1.42-py2.py3-none-any.whl: em_celery/tools/spree/amz_repricer.py <==
# -*- coding: utf-8 -*-

import datetime

import click

from em_tasks.utils.offer_services import AmzOfferService
from em_tasks.utils.price_calculator import PriceCalculator
from em_tasks.utils.spree.amz_repricer import SpreeAmzRepricer
from em_tasks.store.models import *

from em_celery import logger, init_db, get_config, get_amz_offer_filter_config, get_offer_service_config, get_amz_broker_url, get_bot, get_group_chat_id
from em_celery.utils.amz_offers_updater import AmzOffersUpdater


@click.command('Reprice Spree Amazon products')
@click.option('-s', '--store_code', required=True, type=str, help='Store code.')
@click.option('-m', '--marketplace', type=str, default='us')
@click.option('-md', '--dst_marketplace', type=str, default='us')
@click.option('-q', '--qps', type=int, default=10)
def reprice(store_code, marketplace='us', dst_marketplace='us', qps=10):
  init_db()

  marketplace = marketplace.lower()
  dst_marketplace = dst_marketplace.lower()
  filter_cond = get_amz_offer_filter_config(marketplace)
  offer_service_cfg = get_offer_service_config()
  offer_service = AmzOfferService(
    offer_service_cfg['host'], offer_service_cfg['port'],
    offer_service_cfg['user'], offer_service_cfg['password'], filter_cond)

  logger.info('[OfferFilters] %s', filter_cond)

  price_rules = {
    'roi': 0.3,
    'ad_cost': 4.5,
    'transfer_cost': 0
  }

  marketplace = marketplace.lower()
  cfg = get_config()
  if marketplace == dst_marketplace:
    price_rules_key = 'price.rules.amz_{}'.format(marketplace)
    fallback_price_rules_key = price_rules_key
  else:
    price_rules_key = 'price.rules.amz_{}_{}'.format(marketplace, dst_marketplace)
    fallback_price_rules_key = 'price.rules.amz_{}'.format(marketplace)
  price_rules_cfg = cfg.get(price_rules_key, cfg.get(fallback_price_rules_key, dict()))
  for k, v in price_rules_cfg.items():
    price_rules[k] = round(float(v), 2)
  price_calculator = PriceCalculator(price_rules)

  logger.info('[PriceRules] SrcMarketplace: {}, DstMarketplace: {}, Rules: {}'.format(marketplace, dst_marketplace, price_rules))

  broker_url = get_amz_broker_url()
  logger.info('[BrokerURL] %s', broker_url)
  updater = AmzOffersUpdater(broker_url, qps, marketplace, 'new')
  tasks_cnt = updater.tasks_cnt()
  callbacks = [updater.update_offers]
  queue_full = False
  # Don't update offers when queue is full
  if tasks_cnt > 1000:
    callbacks = []
    queue_full = True

  start_time = datetime.datetime.now()

  repricer = SpreeAmzRepricer(store_code, marketplace, offer_service, price_calculator, callbacks)
  repricer.run()

  end_time = datetime.datetime.now()
  total_seconds = round((end_time - start_time).total_seconds())
  if total_seconds > 300:
    stats = repricer.get_stats()
    message = '[AmazonRepricing] Store: {}, Marketplace: {}, QueueFull: {}, Products: {}, Failed: {}, Expired: {}, InStock: {}, OutOfStock: {}, TimeUsed: {}s'.format(
      store_code, marketplace, queue_full, stats['products_cnt'], stats['failed_cnt'], stats['expired_cnt'], stats['in_stock'], stats['out_of_stock'],
      total_seconds)

    bot = get_bot()
    group_chat_id = get_group_chat_id()
    bot.send_message(group_chat_id, message)


if __name__ == "__main__":
  reprice()

==> em_celery-0.1.46-py2.py3-none-any.whl: em_celery/tools/spree/amz_repricer.py <==
# -*- coding: utf-8 -*-

import datetime

import click

from em_tasks.utils.offer_services import AmzOfferService
from em_tasks.utils.price_calculator import PriceCalculator
from em_tasks.utils.spree.amz_repricer import SpreeAmzRepricer
from em_tasks.store.models import *

from em_celery import logger, init_db, get_config, get_amz_offer_filter_config, get_offer_service_config, get_amz_broker_url, get_bot, get_group_chat_id
from em_celery.utils.amz_offers_updater import AmzOffersUpdater


@click.command('Reprice Spree Amazon products')
@click.option('-s', '--store_code', required=True, type=str, help='Store code.')
@click.option('-m', '--marketplace', type=str, default='us')
@click.option('-md', '--dst_marketplace', type=str, default='us')
@click.option('-tc', '--target_currency', type=str, default='USD')
@click.option('-q', '--qps', type=int, default=10)
def reprice(store_code, marketplace='us', dst_marketplace='us', target_currency='USD', qps=10):
  init_db()

  marketplace = marketplace.lower()
  dst_marketplace = dst_marketplace.lower()
  filter_cond = get_amz_offer_filter_config(marketplace)
  offer_service_cfg = get_offer_service_config()
  offer_service = AmzOfferService(
    offer_service_cfg['host'], offer_service_cfg['port'],
    offer_service_cfg['user'], offer_service_cfg['password'], filter_cond)

  logger.info('[OfferFilters] %s', filter_cond)

  price_rules = {
    'roi': 0.3,
    'ad_cost': 4.5,
    'transfer_cost': 0
  }

  marketplace = marketplace.lower()
  cfg = get_config()
  if marketplace == dst_marketplace:
    price_rules_key = 'price.rules.amz_{}'.format(marketplace)
    fallback_price_rules_key = price_rules_key
  else:
    price_rules_key = 'price.rules.amz_{}_{}'.format(marketplace, dst_marketplace)
    fallback_price_rules_key = 'price.rules.amz_{}'.format(marketplace)
  price_rules_cfg = cfg.get(price_rules_key, cfg.get(fallback_price_rules_key, dict()))
  for k, v in price_rules_cfg.items():
    price_rules[k] = round(float(v), 2)
  price_calculator = PriceCalculator(price_rules, target_currency)

  logger.info('[PriceRules] SrcMarketplace: {}, DstMarketplace: {}, Rules: {}'.format(marketplace, dst_marketplace, price_rules))

  broker_url = get_amz_broker_url()
  logger.info('[BrokerURL] %s', broker_url)
  updater = AmzOffersUpdater(broker_url, qps, marketplace, 'new')
  tasks_cnt = updater.tasks_cnt()
  callbacks = [updater.update_offers]
  queue_full = False
  # Don't update offers when queue is full
  if tasks_cnt > 1000:
    callbacks = []
    queue_full = True

  start_time = datetime.datetime.now()

  repricer = SpreeAmzRepricer(store_code, marketplace, offer_service, price_calculator, callbacks)
  repricer.run()

  end_time = datetime.datetime.now()
  total_seconds = round((end_time - start_time).total_seconds())
  if total_seconds > 300:
    stats = repricer.get_stats()
    message = '[AmazonRepricing] Store: {}, Marketplace: {}, QueueFull: {}, Products: {}, Failed: {}, Expired: {}, InStock: {}, OutOfStock: {}, TimeUsed: {}s'.format(
      store_code, marketplace, queue_full, stats['products_cnt'], stats['failed_cnt'], stats['expired_cnt'], stats['in_stock'], stats['out_of_stock'],
      total_seconds)

    bot = get_bot()
    group_chat_id = get_group_chat_id()
    bot.send_message(group_chat_id, message)


if __name__ == "__main__":
  reprice()
